@@ -325,7 +325,8 @@
 *        Added astSame.
 *     7-APR-2010 (DSB):
 *        Added astHasAttribute.
-*--
+*     20-SEP-2018 (DSB):
+*        Added AST__DBL_WIDTH and AST__FLT_WIDTH
 */
 
 /* Include files. */
@@ -408,7 +409,12 @@
   #define AST__FLT_DIG (FLT_DIG + 3)
 #endif
 
-
+/* The number of characters needed to store a floating point value formatted
+   using "%.*g, AST__DBL_DIG". This does not include space for a trailing
+   null. The six extra characters are for the decimal point and the
+   exponent (the exponent occupies up to 5 characters). */
+#define AST__DBL_WIDTH (AST__DBL_DIG + 6)
+#define AST__FLT_WIDTH (AST__FLT_DIG + 6)
 
 
 /*
@@ -1943,16 +1949,19 @@ astINVOKE(V,astTestAttrib_(astCheckObject(this),attrib,STATUS_PTR))
 void astWatchHandle_( int );
 void astHandleUse_( int, const char *, ... );
 void astHandleAlarm_( const char *, va_list );
+void astWatchPointer_( int );
 
 #define astWatchHandle astWatchHandle_
 #define astHandleUse astHandleUse_
 #define astHandleAlarm astHandleAlarm_
+#define astWatchPointer astWatchPointer_
 
 #else
 
 #define astWatchHandle
 #define astHandleUse
 #define astHandleAlarm
+#define astWatchPointer
 
 #endif
 
